@@ -19,7 +19,7 @@
 #include <bsoncxx/config/prelude.hpp>
 
 namespace bsoncxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace builder {
 namespace basic {
 
@@ -37,4 +37,14 @@ BSONCXX_INLINE std::tuple<T&&, U&&> kvp(T&& t, U&& u) {
 }  // namespace v_noabi
 }  // namespace bsoncxx
 
+namespace bsoncxx {
+namespace builder {
+namespace basic {
+
+using ::bsoncxx::v_noabi::builder::basic::kvp;
+
+}  // namespace basic
+}  // namespace builder
+}  // namespace bsoncxx
+
 #include <bsoncxx/config/postlude.hpp>
