@@ -18,7 +18,7 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/document/element.hpp>
 #include <bsoncxx/stdx/string_view.hpp>
-#include <bsoncxx/test_util/catch.hh>
+#include <bsoncxx/test/catch.hh>
 #include <bsoncxx/types.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
 
@@ -366,4 +366,47 @@ TEST_CASE("bson_value::view with inequality for non-value and value",
     b_int64 int64_val{100};
     REQUIRE(int64_val != bson_value::view{b_int64{200}});
 }
+
+TEST_CASE("document uninitialized element throws exceptions", "") {
+    using bsoncxx::builder::basic::kvp;
+    using bsoncxx::builder::basic::make_document;
+    bsoncxx::document::value doc = make_document(kvp("foo", "bar"));
+
+    REQUIRE_THROWS_WITH(doc["doesnotexist"].get_string().value,
+                        Catch::Contains("cannot get string from an uninitialized element with key "
+                                        "\"doesnotexist\": unset document::element"));
+
+    REQUIRE_THROWS_WITH(doc["alsodoesnotexist"].get_value(),
+                        Catch::Contains("cannot return the type of uninitialized element with key "
+                                        "\"alsodoesnotexist\": unset document::element"));
+
+    // Ensure a non-existing element evaluates to false.
+    REQUIRE(!doc["doesnotexist"]);
+    // Ensure finding a non-existing element results in an end iterator.
+    REQUIRE(doc.find("doesnotexist") == doc.cend());
+    // Ensure getting a key from a non-existing element results in an exception.
+    REQUIRE_THROWS_WITH(
+        doc["doesnotexist"].key(),
+        Catch::Contains("cannot return the key from an uninitialized element with key "
+                        "\"doesnotexist\": unset document::element"));
+}
+
+TEST_CASE("array uninitialized element throws exceptions", "") {
+    using bsoncxx::builder::basic::kvp;
+    using bsoncxx::builder::basic::make_array;
+    bsoncxx::array::value arr = make_array("a", "b", "c");
+
+    REQUIRE_THROWS_WITH(arr.view()[3].get_string().value,
+                        Catch::Contains("cannot get string from an uninitialized element with key "
+                                        "\"3\": unset document::element"));
+    // Ensure a non-existing element evaluates to false.
+    REQUIRE(!arr.view()[3]);
+    // Ensure finding a non-existing element results in an end iterator.
+    REQUIRE(arr.view().find(3) == arr.view().cend());
+    // Ensure getting a key from a non-existing element results in an exception.
+    REQUIRE_THROWS_WITH(
+        arr.view()[3].key(),
+        Catch::Contains("cannot return the key from an uninitialized element with key "
+                        "\"3\": unset document::element"));
+}
 }  // namespace
