@@ -14,10 +14,12 @@
 
 #pragma once
 
+#include <mongocxx/options/find_one_common_options-fwd.hpp>
+
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace options {
 
 ///
