@@ -36,13 +36,15 @@
 
 #include <mongocxx/config/private/prelude.hh>
 
-using bsoncxx::builder::concatenate;
-using bsoncxx::builder::basic::kvp;
-using bsoncxx::builder::basic::make_document;
+using bsoncxx::v_noabi::builder::concatenate;
+using bsoncxx::v_noabi::builder::basic::kvp;
+using bsoncxx::v_noabi::builder::basic::make_document;
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
+
 namespace {
+
 class collection_names {
    public:
     explicit collection_names(char** names) {
@@ -64,6 +66,7 @@ class collection_names {
    private:
     char** _names;
 };
+
 }  // namespace
 
 using namespace libbson;
@@ -75,7 +78,8 @@ database& database::operator=(database&&) noexcept = default;
 
 database::~database() = default;
 
-database::database(const class client& client, bsoncxx::string::view_or_value name)
+database::database(const mongocxx::v_noabi::client& client,
+                   bsoncxx::v_noabi::string::view_or_value name)
     : _impl(stdx::make_unique<impl>(
           libmongoc::client_get_database(client._get_impl().client_t, name.terminated().data()),
           &client._get_impl(),
@@ -106,14 +110,14 @@ database::operator bool() const noexcept {
 cursor database::_aggregate(const client_session* session,
                             const pipeline& pipeline,
                             const options::aggregate& options) {
-    scoped_bson_t stages(bsoncxx::document::view(pipeline._impl->view_array()));
+    scoped_bson_t stages(bsoncxx::v_noabi::document::view(pipeline._impl->view_array()));
 
-    bsoncxx::builder::basic::document b;
+    bsoncxx::v_noabi::builder::basic::document b;
 
     options.append(b);
 
     if (session) {
-        b.append(bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+        b.append(bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     scoped_bson_t options_bson(b.view());
@@ -139,13 +143,13 @@ cursor database::aggregate(const client_session& session,
 }
 
 cursor database::_list_collections(const client_session* session,
-                                   bsoncxx::document::view_or_value filter) {
-    bsoncxx::builder::basic::document options_builder;
+                                   bsoncxx::v_noabi::document::view_or_value filter) {
+    bsoncxx::v_noabi::builder::basic::document options_builder;
     options_builder.append(kvp("filter", filter));
 
     if (session) {
         options_builder.append(
-            bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+            bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     scoped_bson_t options_bson(options_builder.extract());
@@ -154,23 +158,23 @@ cursor database::_list_collections(const client_session* session,
                                                           options_bson.bson());
 }
 
-cursor database::list_collections(bsoncxx::document::view_or_value filter) {
+cursor database::list_collections(bsoncxx::v_noabi::document::view_or_value filter) {
     return _list_collections(nullptr, filter);
 }
 
 cursor database::list_collections(const client_session& session,
-                                  bsoncxx::document::view_or_value filter) {
+                                  bsoncxx::v_noabi::document::view_or_value filter) {
     return _list_collections(&session, filter);
 }
 
-std::vector<std::string> database::_list_collection_names(const client_session* session,
-                                                          bsoncxx::document::view_or_value filter) {
-    bsoncxx::builder::basic::document options_builder;
+std::vector<std::string> database::_list_collection_names(
+    const client_session* session, bsoncxx::v_noabi::document::view_or_value filter) {
+    bsoncxx::v_noabi::builder::basic::document options_builder;
     options_builder.append(kvp("filter", filter));
 
     if (session) {
         options_builder.append(
-            bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+            bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     scoped_bson_t options_bson(options_builder.extract());
@@ -191,12 +195,13 @@ std::vector<std::string> database::_list_collection_names(const client_session*
     return _names;
 }
 
-std::vector<std::string> database::list_collection_names(bsoncxx::document::view_or_value filter) {
+std::vector<std::string> database::list_collection_names(
+    bsoncxx::v_noabi::document::view_or_value filter) {
     return _list_collection_names(nullptr, filter);
 }
 
-std::vector<std::string> database::list_collection_names(const client_session& session,
-                                                         bsoncxx::document::view_or_value filter) {
+std::vector<std::string> database::list_collection_names(
+    const client_session& session, bsoncxx::v_noabi::document::view_or_value filter) {
     return _list_collection_names(&session, filter);
 }
 
@@ -204,16 +209,16 @@ stdx::string_view database::name() const {
     return _get_impl().name;
 }
 
-bsoncxx::document::value database::_run_command(const client_session* session,
-                                                bsoncxx::document::view_or_value command) {
+bsoncxx::v_noabi::document::value database::_run_command(
+    const client_session* session, bsoncxx::v_noabi::document::view_or_value command) {
     libbson::scoped_bson_t command_bson{command};
     libbson::scoped_bson_t reply_bson;
     bson_error_t error;
 
-    bsoncxx::builder::basic::document options_builder;
+    bsoncxx::v_noabi::builder::basic::document options_builder;
     if (session) {
         options_builder.append(
-            bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+            bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     scoped_bson_t options_bson(options_builder.extract());
@@ -231,17 +236,18 @@ bsoncxx::document::value database::_run_command(const client_session* session,
     return reply_bson.steal();
 }
 
-bsoncxx::document::value database::run_command(bsoncxx::document::view_or_value command) {
+bsoncxx::v_noabi::document::value database::run_command(
+    bsoncxx::v_noabi::document::view_or_value command) {
     return _run_command(nullptr, command);
 }
 
-bsoncxx::document::value database::run_command(const client_session& session,
-                                               bsoncxx::document::view_or_value command) {
+bsoncxx::v_noabi::document::value database::run_command(
+    const client_session& session, bsoncxx::v_noabi::document::view_or_value command) {
     return _run_command(&session, command);
 }
 
-bsoncxx::document::value database::run_command(bsoncxx::document::view_or_value command,
-                                               uint32_t server_id) {
+bsoncxx::v_noabi::document::value database::run_command(
+    bsoncxx::v_noabi::document::view_or_value command, uint32_t server_id) {
     libbson::scoped_bson_t command_bson{command};
     libbson::scoped_bson_t reply_bson;
     bson_error_t error;
@@ -262,14 +268,15 @@ bsoncxx::document::value database::run_command(bsoncxx::document::view_or_value
     return reply_bson.steal();
 }
 
-collection database::_create_collection(const client_session* session,
-                                        stdx::string_view name,
-                                        bsoncxx::document::view_or_value collection_options,
-                                        const stdx::optional<class write_concern>& write_concern) {
-    bsoncxx::builder::basic::document options_builder;
+collection database::_create_collection(
+    const client_session* session,
+    stdx::string_view name,
+    bsoncxx::v_noabi::document::view_or_value collection_options,
+    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
+    bsoncxx::v_noabi::builder::basic::document options_builder;
     bson_error_t error;
 
-    options_builder.append(bsoncxx::builder::concatenate_doc{collection_options});
+    options_builder.append(bsoncxx::v_noabi::builder::concatenate_doc{collection_options});
 
     if (write_concern) {
         options_builder.append(kvp("writeConcern", write_concern->to_document()));
@@ -277,26 +284,29 @@ collection database::_create_collection(const client_session* session,
 
     if (session) {
         options_builder.append(
-            bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+            bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     libbson::scoped_bson_t opts_bson{options_builder.view()};
-    auto result = libmongoc::database_create_collection(
-        _get_impl().database_t, bsoncxx::string::to_string(name).c_str(), opts_bson.bson(), &error);
+    auto result =
+        libmongoc::database_create_collection(_get_impl().database_t,
+                                              bsoncxx::v_noabi::string::to_string(name).c_str(),
+                                              opts_bson.bson(),
+                                              &error);
 
     if (!result) {
         throw_exception<operation_exception>(error);
     }
 
-    return mongocxx::collection(*this, result);
+    return mongocxx::v_noabi::collection(*this, result);
 }
 
 collection database::_create_collection_deprecated(
     const client_session* session,
-    bsoncxx::string::view_or_value name,
+    bsoncxx::v_noabi::string::view_or_value name,
     const options::create_collection_deprecated& collection_options,
-    const stdx::optional<class write_concern>& write_concern) {
-    bsoncxx::builder::basic::document options_builder;
+    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
+    bsoncxx::v_noabi::builder::basic::document options_builder;
 
     if (collection_options.capped()) {
         options_builder.append(kvp("capped", *collection_options.capped()));
@@ -365,47 +375,49 @@ collection database::_create_collection_deprecated(
     return _create_collection(session, name, options_builder.view(), write_concern);
 }
 
-class collection database::create_collection(
+mongocxx::v_noabi::collection database::create_collection(
     stdx::string_view name,
-    bsoncxx::document::view_or_value collection_options,
-    const stdx::optional<class write_concern>& write_concern) {
+    bsoncxx::v_noabi::document::view_or_value collection_options,
+    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _create_collection(nullptr, name, collection_options, write_concern);
 }
 
-class collection database::create_collection(
+mongocxx::v_noabi::collection database::create_collection(
     const client_session& session,
     stdx::string_view name,
-    bsoncxx::document::view_or_value collection_options,
-    const stdx::optional<class write_concern>& write_concern) {
+    bsoncxx::v_noabi::document::view_or_value collection_options,
+    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _create_collection(&session, name, collection_options, write_concern);
 }
 
-class collection database::create_collection_deprecated(
-    bsoncxx::string::view_or_value name,
+mongocxx::v_noabi::collection database::create_collection_deprecated(
+    bsoncxx::v_noabi::string::view_or_value name,
     const options::create_collection_deprecated& collection_options,
-    const stdx::optional<class write_concern>& write_concern) {
+    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _create_collection_deprecated(nullptr, name, collection_options, write_concern);
 }
 
-class collection database::create_collection_deprecated(
+mongocxx::v_noabi::collection database::create_collection_deprecated(
     const client_session& session,
-    bsoncxx::string::view_or_value name,
+    bsoncxx::v_noabi::string::view_or_value name,
     const options::create_collection_deprecated& collection_options,
-    const stdx::optional<class write_concern>& write_concern) {
+    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _create_collection_deprecated(&session, name, collection_options, write_concern);
 }
 
-void database::_drop(const client_session* session,
-                     const bsoncxx::stdx::optional<mongocxx::write_concern>& write_concern) {
+void database::_drop(
+    const client_session* session,
+    const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     bson_error_t error;
 
-    bsoncxx::builder::basic::document opts_doc;
+    bsoncxx::v_noabi::builder::basic::document opts_doc;
     if (write_concern) {
         opts_doc.append(kvp("writeConcern", write_concern->to_document()));
     }
 
     if (session) {
-        opts_doc.append(bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+        opts_doc.append(
+            bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     libbson::scoped_bson_t opts_bson{opts_doc.view()};
@@ -415,29 +427,31 @@ void database::_drop(const client_session* session,
     }
 }
 
-void database::drop(const bsoncxx::stdx::optional<mongocxx::write_concern>& write_concern) {
+void database::drop(
+    const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _drop(nullptr, write_concern);
 }
 
-void database::drop(const client_session& session,
-                    const bsoncxx::stdx::optional<mongocxx::write_concern>& write_concern) {
+void database::drop(
+    const client_session& session,
+    const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _drop(&session, write_concern);
 }
 
-void database::read_concern(class read_concern rc) {
+void database::read_concern(mongocxx::v_noabi::read_concern rc) {
     libmongoc::database_set_read_concern(_get_impl().database_t, rc._impl->read_concern_t);
 }
 
-class read_concern database::read_concern() const {
+mongocxx::v_noabi::read_concern database::read_concern() const {
     auto rc = libmongoc::database_get_read_concern(_get_impl().database_t);
     return {stdx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc))};
 }
 
-void database::read_preference(class read_preference rp) {
+void database::read_preference(mongocxx::v_noabi::read_preference rp) {
     libmongoc::database_set_read_prefs(_get_impl().database_t, rp._impl->read_preference_t);
 }
 
-bool database::has_collection(bsoncxx::string::view_or_value name) const {
+bool database::has_collection(bsoncxx::v_noabi::string::view_or_value name) const {
     bson_error_t error;
     auto result = libmongoc::database_has_collection(
         _get_impl().database_t, name.terminated().data(), &error);
@@ -448,61 +462,62 @@ bool database::has_collection(bsoncxx::string::view_or_value name) const {
     return result;
 }
 
-class read_preference database::read_preference() const {
-    class read_preference rp(stdx::make_unique<read_preference::impl>(
+mongocxx::v_noabi::read_preference database::read_preference() const {
+    mongocxx::v_noabi::read_preference rp(stdx::make_unique<read_preference::impl>(
         libmongoc::read_prefs_copy(libmongoc::database_get_read_prefs(_get_impl().database_t))));
     return rp;
 }
 
-void database::write_concern(class write_concern wc) {
+void database::write_concern(mongocxx::v_noabi::write_concern wc) {
     libmongoc::database_set_write_concern(_get_impl().database_t, wc._impl->write_concern_t);
 }
 
-class write_concern database::write_concern() const {
-    class write_concern wc(stdx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(
-        libmongoc::database_get_write_concern(_get_impl().database_t))));
+mongocxx::v_noabi::write_concern database::write_concern() const {
+    mongocxx::v_noabi::write_concern wc(
+        stdx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(
+            libmongoc::database_get_write_concern(_get_impl().database_t))));
     return wc;
 }
 
-collection database::collection(bsoncxx::string::view_or_value name) const {
-    return mongocxx::collection(*this, std::move(name));
+collection database::collection(bsoncxx::v_noabi::string::view_or_value name) const {
+    return mongocxx::v_noabi::collection(*this, std::move(name));
 }
 
 gridfs::bucket database::gridfs_bucket(const options::gridfs::bucket& options) const {
     return gridfs::bucket{*this, options};
 }
 
-class change_stream database::watch(const options::change_stream& options) {
+change_stream database::watch(const options::change_stream& options) {
     return watch(pipeline{}, options);
 }
 
-class change_stream database::watch(const client_session& session,
-                                    const options::change_stream& options) {
+change_stream database::watch(const client_session& session,
+                              const options::change_stream& options) {
     return _watch(&session, pipeline{}, options);
 }
 
-class change_stream database::watch(const pipeline& pipe, const options::change_stream& options) {
+change_stream database::watch(const pipeline& pipe, const options::change_stream& options) {
     return _watch(nullptr, pipe, options);
 }
 
-class change_stream database::watch(const client_session& session,
-                                    const pipeline& pipe,
-                                    const options::change_stream& options) {
+change_stream database::watch(const client_session& session,
+                              const pipeline& pipe,
+                              const options::change_stream& options) {
     return _watch(&session, pipe, options);
 }
 
-class change_stream database::_watch(const client_session* session,
-                                     const pipeline& pipe,
-                                     const options::change_stream& options) {
-    bsoncxx::builder::basic::document container;
+change_stream database::_watch(const client_session* session,
+                               const pipeline& pipe,
+                               const options::change_stream& options) {
+    bsoncxx::v_noabi::builder::basic::document container;
     container.append(kvp("pipeline", pipe._impl->view_array()));
     scoped_bson_t pipeline_bson{container.view()};
 
-    bsoncxx::builder::basic::document options_builder;
-    options_builder.append(bsoncxx::builder::concatenate(options.as_bson()));
+    bsoncxx::v_noabi::builder::basic::document options_builder;
+    options_builder.append(bsoncxx::v_noabi::builder::concatenate(options.as_bson()));
     if (session) {
         options_builder.append(
-            bsoncxx::builder::concatenate_doc{session->_get_impl().to_document()});
+            bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
     scoped_bson_t options_bson{options_builder.extract()};
