@@ -17,30 +17,31 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace model {
 
-delete_one::delete_one(bsoncxx::document::view_or_value filter) : _filter(std::move(filter)) {}
+delete_one::delete_one(bsoncxx::v_noabi::document::view_or_value filter)
+    : _filter(std::move(filter)) {}
 
-const bsoncxx::document::view_or_value& delete_one::filter() const {
+const bsoncxx::v_noabi::document::view_or_value& delete_one::filter() const {
     return _filter;
 }
 
-delete_one& delete_one::collation(bsoncxx::document::view_or_value collation) {
+delete_one& delete_one::collation(bsoncxx::v_noabi::document::view_or_value collation) {
     _collation = collation;
     return *this;
 }
 
-const stdx::optional<bsoncxx::document::view_or_value>& delete_one::collation() const {
+const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& delete_one::collation() const {
     return _collation;
 }
 
-delete_one& delete_one::hint(class hint index_hint) {
+delete_one& delete_one::hint(mongocxx::v_noabi::hint index_hint) {
     _hint = std::move(index_hint);
     return *this;
 }
 
-const stdx::optional<class hint>& delete_one::hint() const {
+const stdx::optional<mongocxx::v_noabi::hint>& delete_one::hint() const {
     return _hint;
 }
 
