@@ -17,13 +17,13 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace model {
 
-insert_one::insert_one(bsoncxx::document::view_or_value document)
+insert_one::insert_one(bsoncxx::v_noabi::document::view_or_value document)
     : _document(std::move(document)) {}
 
-const bsoncxx::document::view_or_value& insert_one::document() const {
+const bsoncxx::v_noabi::document::view_or_value& insert_one::document() const {
     return _document;
 }
 
