@@ -17,7 +17,6 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
 namespace libmongoc {
 
 #ifdef MONGOCXX_TESTING
@@ -41,5 +40,4 @@ namespace libmongoc {
 #endif  // MONGOCXX_TESTING
 
 }  // namespace libmongoc
-}  // namespace v_noabi
 }  // namespace mongocxx
