@@ -41,7 +41,6 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
 namespace test_util {
 
 namespace {
@@ -552,5 +551,4 @@ std::string getenv_or_fail(const std::string env_name) {
 }
 
 }  // namespace test_util
-}  // namespace v_noabi
 }  // namespace mongocxx
