@@ -27,7 +27,6 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
 namespace spec {
 
 using namespace mongocxx;
@@ -350,6 +349,6 @@ void apm_checker::clear() {
 }
 
 }  // namespace spec
-}  // namespace v_noabi
 }  // namespace mongocxx
+
 #include <mongocxx/config/private/postlude.hh>
