@@ -45,7 +45,6 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
 namespace spec {
 
 using namespace mongocxx;
@@ -318,7 +317,7 @@ document::value operation_runner::_run_delete_many(document::view operation) {
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -355,7 +354,7 @@ document::value operation_runner::_run_delete_one(document::view operation) {
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -392,14 +391,14 @@ document::value operation_runner::_run_find_one_and_delete(document::view operat
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -461,7 +460,7 @@ document::value operation_runner::_run_find_one_and_replace(document::view opera
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -521,7 +520,7 @@ document::value operation_runner::_run_find_one_and_update(document::view operat
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -677,7 +676,7 @@ document::value operation_runner::_run_replace_one(document::view operation) {
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -745,7 +744,7 @@ document::value operation_runner::_run_update_many(document::view operation) {
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -837,7 +836,7 @@ document::value operation_runner::_run_update_one(document::view operation) {
     }
 
     if (arguments["hint"]) {
-        if (arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+        if (arguments["hint"].type() == bsoncxx::type::k_string)
             options.hint(hint{arguments["hint"].get_string().value});
         else
             options.hint(hint{arguments["hint"].get_document().value});
@@ -996,7 +995,7 @@ document::value operation_runner::_run_bulk_write(document::view operation) {
             auto update_one = _build_update_model<model::update_one>(request_arguments);
 
             if (request_arguments["hint"]) {
-                if (request_arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+                if (request_arguments["hint"].type() == bsoncxx::type::k_string)
                     update_one.hint(hint{request_arguments["hint"].get_string().value});
                 else
                     update_one.hint(hint{request_arguments["hint"].get_document().value});
@@ -1019,7 +1018,7 @@ document::value operation_runner::_run_bulk_write(document::view operation) {
             auto update_many = _build_update_model<model::update_many>(request_arguments);
 
             if (request_arguments["hint"]) {
-                if (request_arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+                if (request_arguments["hint"].type() == bsoncxx::type::k_string)
                     update_many.hint(hint{request_arguments["hint"].get_string().value});
                 else
                     update_many.hint(hint{request_arguments["hint"].get_document().value});
@@ -1043,7 +1042,7 @@ document::value operation_runner::_run_bulk_write(document::view operation) {
             document::view replacement = request_arguments["replacement"].get_document().value;
             model::replace_one replace_one(filter, replacement);
             if (request_arguments["hint"]) {
-                if (request_arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+                if (request_arguments["hint"].type() == bsoncxx::type::k_string)
                     replace_one.hint(hint{request_arguments["hint"].get_string().value});
                 else
                     replace_one.hint(hint{request_arguments["hint"].get_document().value});
@@ -1066,7 +1065,7 @@ document::value operation_runner::_run_bulk_write(document::view operation) {
             document::view filter = request_arguments["filter"].get_document().value;
             model::delete_one delete_one(filter);
             if (request_arguments["hint"]) {
-                if (request_arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+                if (request_arguments["hint"].type() == bsoncxx::type::k_string)
                     delete_one.hint(hint{request_arguments["hint"].get_string().value});
                 else
                     delete_one.hint(hint{request_arguments["hint"].get_document().value});
@@ -1081,7 +1080,7 @@ document::value operation_runner::_run_bulk_write(document::view operation) {
             document::view filter = request_arguments["filter"].get_document().value;
             model::delete_many delete_many(filter);
             if (request_arguments["hint"]) {
-                if (request_arguments["hint"].type() == bsoncxx::v_noabi::type::k_string)
+                if (request_arguments["hint"].type() == bsoncxx::type::k_string)
                     delete_many.hint(hint{request_arguments["hint"].get_string().value});
                 else
                     delete_many.hint(hint{request_arguments["hint"].get_document().value});
@@ -1458,13 +1457,11 @@ document::value operation_runner::run(document::view operation) {
         client client{uri{}};
         auto cursor = client[_db->name()][_coll->name()].list_indexes();
 
-        REQUIRE(cursor.end() ==
-                std::find_if(cursor.begin(),
-                             cursor.end(),
-                             [operation](bsoncxx::v_noabi::document::view doc) {
-                                 return (doc["name"].get_string() ==
-                                         operation["arguments"]["index"].get_string());
-                             }));
+        REQUIRE(
+            cursor.end() ==
+            std::find_if(cursor.begin(), cursor.end(), [operation](bsoncxx::document::view doc) {
+                return (doc["name"].get_string() == operation["arguments"]["index"].get_string());
+            }));
 
         return empty_document;
     } else if (key.compare("assertIndexExists") == 0) {
@@ -1473,13 +1470,11 @@ document::value operation_runner::run(document::view operation) {
         auto collection = operation["arguments"]["collection"].get_string().value;
         auto cursor = client[db][collection].list_indexes();
 
-        REQUIRE(cursor.end() !=
-                std::find_if(cursor.begin(),
-                             cursor.end(),
-                             [operation](bsoncxx::v_noabi::document::view doc) {
-                                 return (doc["name"].get_string() ==
-                                         operation["arguments"]["index"].get_string());
-                             }));
+        REQUIRE(
+            cursor.end() !=
+            std::find_if(cursor.begin(), cursor.end(), [operation](bsoncxx::document::view doc) {
+                return (doc["name"].get_string() == operation["arguments"]["index"].get_string());
+            }));
 
         return empty_document;
     } else if (key.compare("targetedFailPoint") == 0) {
@@ -1508,7 +1503,6 @@ document::value operation_runner::run(document::view operation) {
 }
 
 }  // namespace spec
-}  // namespace v_noabi
 }  // namespace mongocxx
 
 #include <mongocxx/config/private/postlude.hh>
